pub struct RefCellComputeChannel<Server> { /* private fields */ }Expand description
A channel using a ref cell to access the server with mutability.
Important
Only use this channel if you don’t use any threading in your application, otherwise it will panic or cause undefined behaviors.
This is mosly useful for no-std environments where threads aren’t supported, otherwise prefer
the mutex or the mpsc channels.
Implementations
Sourceimpl<Server> RefCellComputeChannel<Server>where
Server: ComputeServer,
impl<Server> RefCellComputeChannel<Server>where
Server: ComputeServer,